You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by di...@apache.org on 2005/12/02 20:24:05 UTC

svn commit: r351806 - in /webservices/axis2/trunk/java/modules: core/src/org/apache/axis2/deployment/ core/src/org/apache/axis2/description/ tool/ideaplugin/plugin/org/apache/idaeplugin/frames/ tool/ideaplugin/plugin/org/apache/idaeplugin/frames/table/

Author: dims
Date: Fri Dec  2 11:23:54 2005
New Revision: 351806

URL: http://svn.apache.org/viewcvs?rev=351806&view=rev
Log:
s/opeartion/operation/g
s/Opeartion/Operation/g


Modified:
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DeploymentEngine.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ModuleBuilder.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ServiceBuilder.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOutAxisOperation.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java
    webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/SelectPanel.java
    webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/table/ArchiveTableModel.java

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DeploymentEngine.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DeploymentEngine.java?rev=351806&r1=351805&r2=351806&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DeploymentEngine.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DeploymentEngine.java Fri Dec  2 11:23:54 2005
@@ -423,8 +423,8 @@
                 axisService.engageModule(module, axisConfig);
             }
 
-            HashMap opeartions = axisService.getOperations();
-            Collection opCol = opeartions.values();
+            HashMap operations = axisService.getOperations();
+            Collection opCol = operations.values();
             for (Iterator iterator = opCol.iterator(); iterator.hasNext();) {
                 AxisOperation opDesc = (AxisOperation) iterator.next();
                 ArrayList modules = opDesc.getModuleRefs();

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java?rev=351806&r1=351805&r2=351806&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java Fri Dec  2 11:23:54 2005
@@ -265,7 +265,7 @@
 
 
     protected void processOperationModuleRefs(Iterator moduleRefs,
-                                              AxisOperation opeartion)
+                                              AxisOperation operation)
             throws DeploymentException {
         try {
             while (moduleRefs.hasNext()) {
@@ -279,7 +279,7 @@
                                 DeploymentErrorMsgs.MODULE_NOT_FOUND,
                                 refName));
                     } else {
-                        opeartion.addModule(new QName(refName));
+                        operation.addModule(new QName(refName));
                     }
                 }
             }

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ModuleBuilder.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ModuleBuilder.java?rev=351806&r1=351805&r2=351806&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ModuleBuilder.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ModuleBuilder.java Fri Dec  2 11:23:54 2005
@@ -107,8 +107,8 @@
             Iterator op_itr = moduleElement.getChildrenWithName(new QName(OPRATIONST));
             ArrayList operations = processOperations(op_itr);
             for (int i = 0; i < operations.size(); i++) {
-                AxisOperation opeartion = (AxisOperation) operations.get(i);
-                module.addOperation(opeartion);
+                AxisOperation operation = (AxisOperation) operations.get(i);
+                module.addOperation(operation);
             }
 
 
@@ -142,7 +142,7 @@
         while (opeartinsItr.hasNext()) {
             OMElement operation = (OMElement) opeartinsItr.next();
 
-            // /getting opeartion name
+            // /getting operation name
             OMAttribute op_name_att = operation.getAttribute(
                     new QName(ATTNAME));
             if(op_name_att == null){
@@ -173,7 +173,7 @@
 //            AxisOperation op_descrip = new AxisOperation();
             op_descrip.setName(new QName(opname));
 
-            //Opeartion Paramters
+            //Operation Paramters
             Iterator paramters = operation.getChildrenWithName(
                     new QName(PARAMETER));
             ArrayList wsamapping =   processParameters(paramters,op_descrip,module);
@@ -204,7 +204,7 @@
             PhasesInfo info = axisConfig.getPhasesinfo();
             info.setOperationPhases(op_descrip);
 
-            //adding the opeartion
+            //adding the operation
             operations.add(op_descrip);
         }
         return operations;

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ServiceBuilder.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ServiceBuilder.java?rev=351806&r1=351805&r2=351806&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ServiceBuilder.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/ServiceBuilder.java Fri Dec  2 11:23:54 2005
@@ -125,13 +125,13 @@
                     new QName(OPRATIONST));
             ArrayList ops = processOperations(opeartinsItr);
             for (int i = 0; i < ops.size(); i++) {
-                AxisOperation opeartionDesc = (AxisOperation) ops.get(i);
-                ArrayList wsamappings = opeartionDesc.getWsamappingList();
+                AxisOperation operationDesc = (AxisOperation) ops.get(i);
+                ArrayList wsamappings = operationDesc.getWsamappingList();
                 for (int j = 0; j < wsamappings.size(); j++) {
                     Parameter paramter = (Parameter) wsamappings.get(j);
-                    service.addMapping((String) paramter.getValue(), opeartionDesc);
+                    service.addMapping((String) paramter.getValue(), operationDesc);
                 }
-                service.addOperation(opeartionDesc);
+                service.addOperation(operationDesc);
             }
 
             Iterator moduleConfigs = service_element.getChildrenWithName(new QName(MODULECONFIG));
@@ -152,7 +152,7 @@
         while (opeartinsItr.hasNext()) {
             OMElement operation = (OMElement) opeartinsItr.next();
 
-            // /getting opeartion name
+            // /getting operation name
             OMAttribute op_name_att = operation.getAttribute(
                     new QName(ATTNAME));
             if (op_name_att == null) {
@@ -187,17 +187,17 @@
                 op_descrip.setName(new QName(opname));
                 log.info(Messages.getMessage(DeploymentErrorMsgs.OP_NOT_FOUN_IN_WSDL, opname));
             } else {
-                //craeting opeartion from existing opeartion
+                //craeting operation from existing operation
                 String mep = wsdlOperation.getMessageExchangePattern();
                 if (mep == null) {
                     op_descrip = new InOutAxisOperation(wsdlOperation);
                 } else {
                     op_descrip = AxisOperationFactory.getOperetionDescription(mep);
-                    op_descrip.setWsdlopeartion((WSDLOperationImpl) wsdlOperation);
+                    op_descrip.setWsdloperation((WSDLOperationImpl) wsdlOperation);
                 }
             }
 
-            //Opeartion Paramters
+            //Operation Paramters
             Iterator paramters = operation.getChildrenWithName(
                     new QName(PARAMETER));
             ArrayList wsamappings = processParameters(paramters, op_descrip, service);
@@ -233,7 +233,7 @@
             Iterator moduleConfigs = operation.getChildrenWithName(new QName(MODULECONFIG));
             processOperationModuleConfig(moduleConfigs, op_descrip, op_descrip);
 
-            //adding the opeartion
+            //adding the operation
             operations.add(op_descrip);
         }
         return operations;
@@ -278,7 +278,7 @@
 
     protected void processOperationModuleConfig(Iterator moduleConfigs,
                                                 ParameterInclude parent,
-                                                AxisOperation opeartion)
+                                                AxisOperation operation)
             throws DeploymentException {
         while (moduleConfigs.hasNext()) {
             OMElement moduleConfig = (OMElement) moduleConfigs.next();
@@ -293,7 +293,7 @@
                         new ModuleConfiguration(new QName(module), parent);
                 Iterator paramters = moduleConfig.getChildrenWithName(new QName(PARAMETER));
                 processParameters(paramters, moduleConfiguration, parent);
-                opeartion.addModuleConfig(moduleConfiguration);
+                operation.addModuleConfig(moduleConfiguration);
             }
         }
     }

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java?rev=351806&r1=351805&r2=351806&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java Fri Dec  2 11:23:54 2005
@@ -52,7 +52,7 @@
 
     private int mep = MEP_CONSTANT_INVALID;
 
-    private WSDLOperationImpl wsdlopeartion;
+    private WSDLOperationImpl wsdloperation;
 
     private AxisService parent;
     private ArrayList wsamappingList;
@@ -65,8 +65,8 @@
     private ArrayList engagedModules = new ArrayList();
 
 
-    public AxisOperation(WSDLOperation wsdlopeartion) {
-        this.wsdlopeartion = (WSDLOperationImpl) wsdlopeartion;
+    public AxisOperation(WSDLOperation wsdloperation) {
+        this.wsdloperation = (WSDLOperationImpl) wsdloperation;
         this.setMessageExchangePattern(MEP_URI_IN_OUT);
         this.setComponentProperty(PARAMETER_KEY, new ParameterIncludeImpl());
         modulerefs = new ArrayList();
@@ -296,143 +296,143 @@
             throws AxisFault;
 
     public List getInfaults() {
-        return wsdlopeartion.getInfaults();
+        return wsdloperation.getInfaults();
     }
 
     public void setInfaults(List infaults) {
-        wsdlopeartion.setInfaults(infaults);
+        wsdloperation.setInfaults(infaults);
     }
 
     public MessageReference getInputMessage() {
-        return wsdlopeartion.getInputMessage();
+        return wsdloperation.getInputMessage();
     }
 
     public void setInputMessage(MessageReference inputMessage) {
-        wsdlopeartion.setInputMessage(inputMessage);
+        wsdloperation.setInputMessage(inputMessage);
     }
 
     public String getMessageExchangePattern() {
-        return wsdlopeartion.getMessageExchangePattern();
+        return wsdloperation.getMessageExchangePattern();
     }
 
     public void setMessageExchangePattern(String messageExchangePattern) {
-        wsdlopeartion.setMessageExchangePattern(messageExchangePattern);
+        wsdloperation.setMessageExchangePattern(messageExchangePattern);
     }
 
     public QName getName() {
-        return wsdlopeartion.getName();
+        return wsdloperation.getName();
     }
 
     public void setName(QName name) {
-        wsdlopeartion.setName(name);
+        wsdloperation.setName(name);
     }
 
     public List getOutfaults() {
-        return wsdlopeartion.getOutfaults();
+        return wsdloperation.getOutfaults();
     }
 
     public void setOutfaults(List outfaults) {
-        wsdlopeartion.setOutfaults(outfaults);
+        wsdloperation.setOutfaults(outfaults);
     }
 
     public MessageReference getOutputMessage() {
-        return wsdlopeartion.getOutputMessage();
+        return wsdloperation.getOutputMessage();
     }
 
     public void setOutputMessage(MessageReference outputMessage) {
-        wsdlopeartion.setOutputMessage(outputMessage);
+        wsdloperation.setOutputMessage(outputMessage);
     }
 
     public boolean isSafe() {
-        return wsdlopeartion.isSafe();
+        return wsdloperation.isSafe();
     }
 
     public void setSafety(boolean safe) {
-        wsdlopeartion.setSafety(safe);
+        wsdloperation.setSafety(safe);
     }
 
     public String getStyle() {
-        return wsdlopeartion.getStyle();
+        return wsdloperation.getStyle();
     }
 
     public void setStyle(String style) {
-        wsdlopeartion.setStyle(style);
+        wsdloperation.setStyle(style);
     }
 
     public String getTargetnamespace() {
-        return wsdlopeartion.getTargetnamespace();
+        return wsdloperation.getTargetnamespace();
     }
 
     public void addInFault(WSDLFaultReference inFault) {
-        wsdlopeartion.addInFault(inFault);
+        wsdloperation.addInFault(inFault);
     }
 
     public void addOutFault(WSDLFaultReference outFault) {
-        wsdlopeartion.addOutFault(outFault);
+        wsdloperation.addOutFault(outFault);
     }
 
     public void addFeature(WSDLFeature feature) {
-        wsdlopeartion.addFeature(feature);
+        wsdloperation.addFeature(feature);
     }
 
     public List getFeatures() {
-        return wsdlopeartion.getFeatures();
+        return wsdloperation.getFeatures();
     }
 
     public void addProperty(WSDLProperty wsdlProperty) {
-        wsdlopeartion.addProperty(wsdlProperty);
+        wsdloperation.addProperty(wsdlProperty);
     }
 
     public List getProperties() {
-        return wsdlopeartion.getProperties();
+        return wsdloperation.getProperties();
     }
 
     public Document getDocumentation() {
-        return wsdlopeartion.getDocumentation();
+        return wsdloperation.getDocumentation();
     }
 
     public void setDocumentation(Document documentation) {
-        wsdlopeartion.setDocumentation(documentation);
+        wsdloperation.setDocumentation(documentation);
     }
 
     public HashMap getComponentProperties() {
-        return wsdlopeartion.getComponentProperties();
+        return wsdloperation.getComponentProperties();
     }
 
     public void setComponentProperties(HashMap properties) {
-        wsdlopeartion.setComponentProperties(properties);
+        wsdloperation.setComponentProperties(properties);
     }
 
     public void setComponentProperty(Object key, Object obj) {
-        wsdlopeartion.setComponentProperty(key, obj);
+        wsdloperation.setComponentProperty(key, obj);
     }
 
     public Object getComponentProperty(Object key) {
-        return wsdlopeartion.getComponentProperty(key);
+        return wsdloperation.getComponentProperty(key);
     }
 
     public void addExtensibilityElement(WSDLExtensibilityElement element) {
-        wsdlopeartion.addExtensibilityElement(element);
+        wsdloperation.addExtensibilityElement(element);
     }
 
     public List getExtensibilityElements() {
-        return wsdlopeartion.getExtensibilityElements();
+        return wsdloperation.getExtensibilityElements();
     }
 
     public void addExtensibleAttributes(WSDLExtensibilityAttribute attribute) {
-        wsdlopeartion.addExtensibleAttributes(attribute);
+        wsdloperation.addExtensibleAttributes(attribute);
     }
 
     public List getExtensibilityAttributes() {
-        return wsdlopeartion.getExtensibilityAttributes();
+        return wsdloperation.getExtensibilityAttributes();
     }
 
     public Map getMetadataBag() {
-        return wsdlopeartion.getMetadataBag();
+        return wsdloperation.getMetadataBag();
     }
 
     public void setMetadataBag(Map meMap) {
-        wsdlopeartion.setMetadataBag(meMap);
+        wsdloperation.setMetadataBag(meMap);
     }
 
 
@@ -531,8 +531,8 @@
         }
     }
 
-    public void setWsdlopeartion(WSDLOperationImpl wsdlopeartion) {
-        this.wsdlopeartion = wsdlopeartion;
+    public void setWsdloperation(WSDLOperationImpl wsdloperation) {
+        this.wsdloperation = wsdloperation;
     }
 
     public ArrayList getWsamappingList() {

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOutAxisOperation.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOutAxisOperation.java?rev=351806&r1=351805&r2=351806&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOutAxisOperation.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/InOutAxisOperation.java Fri Dec  2 11:23:54 2005
@@ -39,8 +39,8 @@
     private AxisMessage outFaultMessage;
     private AxisMessage outMessage;
 
-    public InOutAxisOperation(WSDLOperation wsdlopeartion) {
-        super(wsdlopeartion);
+    public InOutAxisOperation(WSDLOperation wsdloperation) {
+        super(wsdloperation);
         createMessages();
     }
 

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java?rev=351806&r1=351805&r2=351806&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/SelectPanel.java (original)
+++ webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/SelectPanel.java Fri Dec  2 11:23:54 2005
@@ -60,7 +60,7 @@
     protected MainFrame parent;
     protected String fileName;
     protected int count = 1;
-    protected HashMap opeartions;
+    protected HashMap operations;
     protected ArrayList servicelsit = new ArrayList();
     protected DescriptorFile disfile;
     protected String sgXMl;
@@ -177,18 +177,18 @@
                 ClassLoader classLoader = parent.bean.getClassLoader();
                 Class serCla= Class.forName(fileName,true,classLoader);
                 Method[] methods =  serCla.getDeclaredMethods();
-                opeartions = new HashMap();
+                operations = new HashMap();
                 if(methods.length >0){
                     for (int i = 0; i < methods.length; i++) {
                         Method method = methods[i];
                         OprationObj Operationobj = new OprationObj(method.getName(),
                                 method.getReturnType().toString(),
                                 new Integer(method.getParameterTypes().length),new Boolean(true));
-                        opeartions.put(method.getName() ,Operationobj);
+                        operations.put(method.getName() ,Operationobj);
                     }
                 }
 
-                ArchiveTableModel myModel = new ArchiveTableModel(opeartions);
+                ArchiveTableModel myModel = new ArchiveTableModel(operations);
                 JTable table = new JTable(myModel);
                 tablelbl = new JLabel("Select Operation you want to publish ") ;
                 add(tablelbl);
@@ -210,7 +210,7 @@
         } else if(obj == butDone){
 
             ArrayList ops = new ArrayList();
-            Iterator opitr = opeartions.values().iterator();
+            Iterator opitr = operations.values().iterator();
             while (opitr.hasNext()) {
                 OprationObj oprationObj = (OprationObj) opitr.next();
                 if(oprationObj.getSelect().booleanValue()){

Modified: webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/table/ArchiveTableModel.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/table/ArchiveTableModel.java?rev=351806&r1=351805&r2=351806&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/table/ArchiveTableModel.java (original)
+++ webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/table/ArchiveTableModel.java Fri Dec  2 11:23:54 2005
@@ -30,7 +30,7 @@
  */
 public class ArchiveTableModel extends AbstractTableModel {
 
-    final String[] columnNames = {"Opeartion Name", "Return Value", "Paramters ", "Select"};
+    final String[] columnNames = {"Operation Name", "Return Value", "Paramters ", "Select"};
     Object [][] datvalue;
     private HashMap datobjs;
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java Fri Dec  2 11:23:54 2005
@@ -51,8 +51,8 @@
      */
     private final FlowInclude flowInclude = new FlowIncludeImpl();
 
-    //to store module opeartions , which are suppose to be added to a service if it is engaged to a service
-    private HashMap opeartions;
+    //to store module operations , which are suppose to be added to a service if it is engaged to a service
+    private HashMap operations;
 
     /**
      * Field parameters
@@ -63,7 +63,7 @@
      * Constructor ModuleDescription
      */
     public ModuleDescription() {
-        opeartions = new HashMap();
+        operations = new HashMap();
     }
 
     /**
@@ -181,11 +181,11 @@
     }
 
     public void addOperation(AxisOperation axisOperation) {
-        opeartions.put(axisOperation.getName(), axisOperation);
+        operations.put(axisOperation.getName(), axisOperation);
     }
 
     public HashMap getOperations() {
-        return opeartions;
+        return operations;
     }
 
     public AxisConfiguration getParent() {

Modified: webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/SelectPanel.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/tool/ideaplugin/plugin/org/apache/idaeplugin/frames/SelectPanel.java?rev=351806&r1=351805&r2=351806&view=diff
==============================================================================